systemtools.Configuration
=========================

.. abjad-lineage:: abjad.tools.systemtools.Configuration.Configuration

.. autoclass:: abjad.tools.systemtools.Configuration.Configuration

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.systemtools.Configuration.Configuration.configuration_directory
      ~abjad.tools.systemtools.Configuration.Configuration.configuration_file_name
      ~abjad.tools.systemtools.Configuration.Configuration.configuration_file_path
      ~abjad.tools.systemtools.Configuration.Configuration.home_directory
      ~abjad.tools.systemtools.Configuration.Configuration.__delitem__
      ~abjad.tools.systemtools.Configuration.Configuration.__eq__
      ~abjad.tools.systemtools.Configuration.Configuration.__format__
      ~abjad.tools.systemtools.Configuration.Configuration.__getitem__
      ~abjad.tools.systemtools.Configuration.Configuration.__hash__
      ~abjad.tools.systemtools.Configuration.Configuration.__iter__
      ~abjad.tools.systemtools.Configuration.Configuration.__len__
      ~abjad.tools.systemtools.Configuration.Configuration.__ne__
      ~abjad.tools.systemtools.Configuration.Configuration.__repr__
      ~abjad.tools.systemtools.Configuration.Configuration.__setitem__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.systemtools.Configuration.Configuration.configuration_directory
   :noindex:

.. autoattribute:: abjad.tools.systemtools.Configuration.Configuration.configuration_file_name
   :noindex:

.. autoattribute:: abjad.tools.systemtools.Configuration.Configuration.configuration_file_path
   :noindex:

.. autoattribute:: abjad.tools.systemtools.Configuration.Configuration.home_directory
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.systemtools.Configuration.Configuration.__delitem__
   :noindex:

.. automethod:: abjad.tools.systemtools.Configuration.Configuration.__eq__
   :noindex:

.. automethod:: abjad.tools.systemtools.Configuration.Configuration.__format__
   :noindex:

.. automethod:: abjad.tools.systemtools.Configuration.Configuration.__getitem__
   :noindex:

.. automethod:: abjad.tools.systemtools.Configuration.Configuration.__hash__
   :noindex:

.. automethod:: abjad.tools.systemtools.Configuration.Configuration.__iter__
   :noindex:

.. automethod:: abjad.tools.systemtools.Configuration.Configuration.__len__
   :noindex:

.. automethod:: abjad.tools.systemtools.Configuration.Configuration.__ne__
   :noindex:

.. automethod:: abjad.tools.systemtools.Configuration.Configuration.__repr__
   :noindex:

.. automethod:: abjad.tools.systemtools.Configuration.Configuration.__setitem__
   :noindex:
